[systemd-commits] 2 commits - TODO man/systemd-inhibit.xml man/systemd-logind.service.xml man/systemd-remount-fs.service.xml src/core src/remount-fs

Lennart Poettering lennart at kemper.freedesktop.org
Fri Jun 29 07:14:50 PDT 2012


 TODO                               |   13 +++++++++++++
 man/systemd-inhibit.xml            |   28 +++++++++++++++++++++++-----
 man/systemd-logind.service.xml     |    7 ++++++-
 man/systemd-remount-fs.service.xml |   29 +++++++++++++++--------------
 src/core/dbus-manager.c            |    4 +++-
 src/remount-fs/remount-fs.c        |    5 +++--
 6 files changed, 63 insertions(+), 23 deletions(-)

New commits:
commit b4efdf97203ddf781c17f77be84cc61516a077d2
Author: Lennart Poettering <lennart at poettering.net>
Date:   Fri Jun 29 16:14:01 2012 +0200

    remount-fs: also remount /usr according to fstab

diff --git a/TODO b/TODO
index 01b5edc..c51bfbe 100644
--- a/TODO
+++ b/TODO
@@ -25,6 +25,15 @@ Bugfixes:
 
 Features:
 
+* document that journal data is primarily ASCII, UTF-8 where necessary and binary only where nothing else makes sense.
+
+* on reload/reexec: serialize NInstalledJobs properly
+
+* Document:
+        - PID 1 D-Bus API
+        - Update Syslog Interface docs
+        - Journal C API manual pages
+
 * logind: export a bool property that tells user whether a
   suspend/shutdown is currently scheduled, i.e. where are between
   PrepareForSuspend(true) and PrepareForSuspend(false)
diff --git a/man/systemd-remount-fs.service.xml b/man/systemd-remount-fs.service.xml
index fa3b009..c1df5e6 100644
--- a/man/systemd-remount-fs.service.xml
+++ b/man/systemd-remount-fs.service.xml
@@ -58,20 +58,21 @@
                 is an early-boot service that applies mount options
                 listed in
                 <citerefentry><refentrytitle>fstab</refentrytitle><manvolnum>5</manvolnum></citerefentry>
-                to the root file system and the kernel API virtual
-                file systems. This is required so that the mount
-                options of these file systems -- which are pre-mounted
-                by the kernel, the initial RAM disk or system manager
-                code -- are updated to those listed in
-                <filename>/etc/fstab</filename>. This service ignores
-                normal file systems and only changes the root file
-                system (i.e. <filename>/</filename>) and the virtual
-                kernel API file systems such as
-                <filename>/proc</filename>, <filename>/sys</filename>
-                or <filename>/dev/</filename>. This service executes
-                no operation if <filename>/etc/fstab</filename> does
-                not exist or lists no entries for the root file system
-                or the kernel API VFS.</para>
+                to the root file system, the <filename>/usr</filename>
+                file system and the kernel API virtual file
+                systems. This is required so that the mount options of
+                these file systems -- which are pre-mounted by the
+                kernel, the initial RAM disk, container environments
+                or system manager code -- are updated to those listed
+                in <filename>/etc/fstab</filename>. This service
+                ignores normal file systems and only changes the root
+                file system (i.e. <filename>/</filename>),
+                <filename>/usr</filename> and the virtual kernel API
+                file systems such as <filename>/proc</filename>,
+                <filename>/sys</filename> or
+                <filename>/dev/</filename>. This service executes no
+                operation if <filename>/etc/fstab</filename> does not
+                exist or lists no entries for the mentioned file systems.</para>
         </refsect1>
 
         <refsect1>
diff --git a/src/core/dbus-manager.c b/src/core/dbus-manager.c
index cd827ca..f8a5400 100644
--- a/src/core/dbus-manager.c
+++ b/src/core/dbus-manager.c
@@ -114,7 +114,9 @@
         "  </method>\n"                                                 \
         "  <method name=\"Subscribe\"/>\n"                              \
         "  <method name=\"Unsubscribe\"/>\n"                            \
-        "  <method name=\"Dump\"/>\n"                                   \
+        "  <method name=\"Dump\">\n"                                    \
+        "   <arg name=\"dump\" type=\"s\" direction=\"out\"/>\n"        \
+        "  </method>\n"                                                 \
         "  <method name=\"CreateSnapshot\">\n"                          \
         "   <arg name=\"name\" type=\"s\" direction=\"in\"/>\n"         \
         "   <arg name=\"cleanup\" type=\"b\" direction=\"in\"/>\n"      \
diff --git a/TODO b/TODO
index 0496c06..01b5edc 100644
--- a/TODO
+++ b/TODO
@@ -25,6 +25,10 @@ Bugfixes:
 
 Features:
 
+* logind: export a bool property that tells user whether a
+  suspend/shutdown is currently scheduled, i.e. where are between
+  PrepareForSuspend(true) and PrepareForSuspend(false)
+
 * support debian's console-setup logic
 
 * introduce Type=pid-file
diff --git a/man/systemd-inhibit.xml b/man/systemd-inhibit.xml
index bea4724..81ec9ef 100644
--- a/man/systemd-inhibit.xml
+++ b/man/systemd-inhibit.xml
@@ -71,6 +71,10 @@
                 to avoid system suspends while an optical disc is
                 being recorded, or similar operations that should not
                 be interrupted.</para>
+
+                <para>For more information see the <ulink
+                url="http://www.freedesktop.org/wiki/Software/systemd/inhibit">Inhibitor
+                Lock Developer Documentation</ulink>.</para>
         </refsect1>
 
         <refsect1>
@@ -103,10 +107,14 @@
                                 <literal>shutdown</literal>,
                                 <literal>sleep</literal>,
                                 <literal>idle</literal>, for
-                                inhibiting reboot/power-off/halt/kexec,
+                                inhibiting
+                                reboot/power-off/halt/kexec,
                                 suspending/hibernating, resp. the
-                                automatic idle
-                                detection.</para></listitem>
+                                automatic idle detection. If ommitted
+                                defaults to
+                                <literal>idle:sleep:shutdown</literal>,
+                                i.e. takes all possible
+                                locks.</para></listitem>
                         </varlistentry>
 
                         <varlistentry>
@@ -156,8 +164,6 @@
                                 inhibition locks instead of acquiring
                                 one.</para></listitem>
                         </varlistentry>
-
-
                 </variablelist>
 
         </refsect1>
@@ -169,6 +175,18 @@
         </refsect1>
 
         <refsect1>
+                <title>Example</title>
+
+                <programlisting># systemd-inhibit wodim foobar.iso</programlisting>
+
+                <para>This burns the ISO image
+                <filename>foobar.iso</filename> on a CD using
+                <citerefentry><refentrytitle>wodim</refentrytitle><manvolnum>1</manvolnum></citerefentry>,
+                and inhibits system sleeping, shutdown and idle while
+                doing so.</para>
+        </refsect1>
+
+        <refsect1>
                 <title>See Also</title>
                 <para>
                         <citerefentry><refentrytitle>systemd</refentrytitle><manvolnum>1</manvolnum></citerefentry>,
diff --git a/man/systemd-logind.service.xml b/man/systemd-logind.service.xml
index 05fcde3..436c277 100644
--- a/man/systemd-logind.service.xml
+++ b/man/systemd-logind.service.xml
@@ -109,9 +109,14 @@
 
                 <para>See the <ulink
                 url="http://www.freedesktop.org/wiki/Software/systemd/logind">
-                developer documentation</ulink> for information about
+                logind D-Bus API Documentation</ulink> for information about
                 the APIs <filename>systemd-logind</filename>
                 provides.</para>
+
+                <para>For more information on the inhibition logic see
+                the <ulink
+                url="http://www.freedesktop.org/wiki/Software/systemd/inhibit">Inhibitor
+                Lock Developer Documentation</ulink>.</para>
         </refsect1>
 
         <refsect1>



More information about the systemd-commits mailing list
diff --git a/src/remount-fs/remount-fs.c b/src/remount-fs/remount-fs.c
index ef68e50..8b3aaeb 100644
--- a/src/remount-fs/remount-fs.c
+++ b/src/remount-fs/remount-fs.c
@@ -79,9 +79,10 @@ int main(int argc, char *argv[]) {
                 int k;
                 char *s;
 
                 /* Remount the root fs and all API VFS */
                 if (!mount_point_is_api(me->mnt_dir) &&
-                    !path_equal(me->mnt_dir, "/"))
+                    !path_equal(me->mnt_dir, "/") &&
+                    !path_equal(me->mnt_dir, "/usr"))
                         continue;
 
                 log_debug("Remounting %s", me->mnt_dir);
@@ -79,9 +79,10 @@ int main(int argc, char *argv[]) {
                 char *s;
 
-                /* Remount the root fs and all API VFS */
+                /* Remount the root fs, /usr and all API VFS */
                 if (!mount_point_is_api(me->mnt_dir) &&

commit 5b6a2c5aab9893ba82acf90696f83e4d48db2b19
Author: Lennart Poettering <lennart at poettering.net>
Date:   Fri Jun 29 02:07:40 2012 +0200

    man: add references to the new inhibitor lock documentation
